@@ -5,8 +5,9 @@
 (autoload 'custom-add-loads "cus-load")
 
 (custom-add-loads 'message '("sendmail"))
+(custom-add-loads 'starttls '("starttls"))
 (custom-add-loads 'mail-abbrevs '("mail-abbrevs"))
-(custom-add-loads 'mail '("mail-utils" "highlight-headers" "mail-abbrevs" "mail-extr" "rmail-mini" "smtpmail"))
+(custom-add-loads 'mail '("mail-utils" "highlight-headers" "mail-abbrevs" "mail-extr" "rmail-mini" "smtpmail" "starttls"))
 (custom-add-loads 'rmail-reply '("rmail-mini"))
 (custom-add-loads 'hypermedia '("browse-url"))
 (custom-add-loads 'highlight-headers-faces '("highlight-headers"))
