@@ -442,20 +442,17 @@ This is relative to `smtpmail-queue-dir'.")
 		    (and (eq (length name) 1)
 			 (setq name (car name)))
 		    (and name
-			 (cond ((memq name '(verb xvrb 8bitmime onex xone
-						  expn size dsn etrn 
-						  enhancedstatuscodes
-						  help xusr
-						  auth=login auth starttls))
-				(setq supported-extensions
-				      (cons name supported-extensions)))
-			       ((and (consp name) (memq (car name) '(auth)))
-				(setq supported-extensions
-				      (cons name supported-extensions)))
-			       (t (message "unknown extension %s"
-					   name)))))
+			 (if (memq (if (consp name) (car name) name)
+				   '(verb xvrb 8bitmime onex xone
+					  expn size dsn etrn 
+					  enhancedstatuscodes
+					  help xusr
+					  auth=login auth starttls))
+			     (setq supported-extensions
+				   (cons name supported-extensions))
+			   (message "unknown extension %s" name))))
 		  (setq extension-lines (cdr extension-lines)))))
-
+	  
 	    (if (and (smtpmail-find-credentials smtpmail-starttls-credentials host port)
 		     (member 'starttls supported-extensions)
 		     (process-id process))
@@ -536,7 +533,8 @@ This is relative to `smtpmail-queue-dir'.")
 
 	    ;; MAIL FROM: <sender>
 	    (let ((size-part
-		   (if (member 'size supported-extensions)
+		   (if (or (member 'size supported-extensions)
+			   (assoc 'size supported-extensions))
 		       (format " SIZE=%d"
 			       (save-excursion
 				 (set-buffer smtpmail-text-buffer)
